==> kadu_1.0.orig.tar.bz2: kadu-1.0/plugins/profiles_import/translations/profiles_import_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>ImportProfileWindow</name>
    <message>
        <source>Import external Kadu 0.6.5 profile</source>
        <translation>Import zewnętrznego profilu Kadu 0.6.5</translation>
    </message>
    <message>
        <source>Select profile path</source>
        <translation>Wybierz ścieżkę do profilu</translation>
    </message>
    <message>
        <source>Select profile path:</source>
        <translation>Wybierz ścieżkę do profilu:</translation>
    </message>
    <message>
        <source>Select imported account identity:</source>
        <translation>Wybierz tożsamość dla importowanego konta:</translation>
    </message>
    <message>
        <source>Import history</source>
        <translation>Importuj historię</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>&lt;b&gt;Identity not selected&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nie wybrano tożsamości&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Selected directory does not contain kadu.conf.xml file&lt;/b&gt;</source>
        <translation>&lt;b&gt;Wybrany katalog nie zawiera pliku kadu.conf.xml&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation>Importuj zewnętrzny profil...</translation>
    </message>
    <message>
        <source>This directory is not a Kadu profile directory.
File kadu.conf.xml not found</source>
        <translation>Ten katalog nie zawiera poprawnego profilu Kadu.
Plik kadu.conf.xml nie został odnaleziony</translation>
    </message>
    <message>
        <source>Profile successfully imported!</source>
        <translation>Import profilu zakończony sukcesem!</translation>
    </message>
    <message>
        <source>Unable to import profile: %1</source>
        <translation>Nie można zaimportować profilu: %1</translation>
    </message>
</context>
<context>
    <name>ImportProfilesWindow</name>
    <message>
        <source>&lt;p&gt;Current version of Kadu does not support user profiles.&lt;br /&gt;Instead, multiple account are supported in one instances of kadu.&lt;/p&gt;&lt;p&gt;Please select profiles that you would like to import as&lt;br /&gt;account into this instance of Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt; Aktualna wersja Kadu nie obsługuje profili użytkowników.&lt;br /&gt;Zamiast tego, wiele kont jest obsługiwanych w jednej instancji Kadu. &lt;/p&gt;&lt;p&gt; Proszę wybrać profile, które chcesz zaimportować jako&lt;br /&gt;konta do tej instancji Kadu. &lt;/p&gt;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Import history</source>
        <translation>Importuj historię</translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation>Importuj zewnętrzny profil...</translation>
    </message>
    <message>
        <source>Profile %1 successfully imported!</source>
        <translation>Import profilu %1 zakończony sukcesem!</translation>
    </message>
    <message>
        <source>Import profile...</source>
        <translation>Importuj profil...</translation>
    </message>
    <message>
        <source>Unable to import profile: %1: %2</source>
        <translation>Nie można zaimportować profilu: %1: %2</translation>
    </message>
</context>
<context>
    <name>ProfileImporter</name>
    <message>
        <source>Unable to open profile file [%1].</source>
        <translation>Nie można otworzyć pliku profilu: [%1].</translation>
    </message>
    <message>
        <source>Account already exists.</source>
        <translation>Konto już istnieje.</translation>
    </message>
    <message>
        <source>Imported account has no ID</source>
        <translation>Zaimportowane konto nie posiada ID</translation>
    </message>
</context>
<context>
    <name>ProfilesImportActions</name>
    <message>
        <source>Import profiles...</source>
        <translation>Importuj profil...</translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation>Importuj zewnętrzny profil...</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/profiles_import/translations/profiles_import_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ImportProfileWindow</name>
    <message>
        <source>Import external Kadu 0.6.5 profile</source>
        <translation>Import zewnętrznego profilu Kadu 0.6.5</translation>
    </message>
    <message>
        <source>Select profile path</source>
        <translation>Wybierz ścieżkę do profilu</translation>
    </message>
    <message>
        <source>Select profile path:</source>
        <translation>Wybierz ścieżkę do profilu:</translation>
    </message>
    <message>
        <source>Select imported account identity:</source>
        <translation>Wybierz tożsamość dla importowanego konta:</translation>
    </message>
    <message>
        <source>Import history</source>
        <translation>Importuj historię</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>&lt;b&gt;Identity not selected&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nie wybrano tożsamości&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Selected directory does not contain kadu.conf.xml file&lt;/b&gt;</source>
        <translation>&lt;b&gt;Wybrany katalog nie zawiera pliku kadu.conf.xml&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation>Importuj zewnętrzny profil...</translation>
    </message>
    <message>
        <source>This directory is not a Kadu profile directory.
File kadu.conf.xml not found</source>
        <translation>Ten katalog nie zawiera poprawnego profilu Kadu.
Plik kadu.conf.xml nie został odnaleziony</translation>
    </message>
    <message>
        <source>Profile successfully imported!</source>
        <translation>Import profilu zakończony sukcesem!</translation>
    </message>
    <message>
        <source>Unable to import profile: %1</source>
        <translation>Nie można zaimportować profilu: %1</translation>
    </message>
</context>
<context>
    <name>ImportProfilesWindow</name>
    <message>
        <source>&lt;p&gt;Current version of Kadu does not support user profiles.&lt;br /&gt;Instead, multiple account are supported in one instances of kadu.&lt;/p&gt;&lt;p&gt;Please select profiles that you would like to import as&lt;br /&gt;account into this instance of Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt; Aktualna wersja Kadu nie obsługuje profili użytkowników.&lt;br /&gt;Zamiast tego, wiele kont jest obsługiwanych w jednej instancji Kadu. &lt;/p&gt;&lt;p&gt; Proszę wybrać profile, które chcesz zaimportować jako&lt;br /&gt;konta do tej instancji Kadu. &lt;/p&gt;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Import history</source>
        <translation>Importuj historię</translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation>Importuj zewnętrzny profil...</translation>
    </message>
    <message>
        <source>Profile %1 successfully imported!</source>
        <translation>Import profilu %1 zakończony sukcesem!</translation>
    </message>
    <message>
        <source>Import profile...</source>
        <translation>Importuj profil...</translation>
    </message>
    <message>
        <source>Unable to import profile: %1: %2</source>
        <translation>Nie można zaimportować profilu: %1: %2</translation>
    </message>
</context>
<context>
    <name>ProfileImporter</name>
    <message>
        <source>Unable to open profile file [%1].</source>
        <translation>Nie można otworzyć pliku profilu: [%1].</translation>
    </message>
    <message>
        <source>Account already exists.</source>
        <translation>Konto już istnieje.</translation>
    </message>
    <message>
        <source>Imported account has no ID</source>
        <translation>Zaimportowane konto nie posiada ID</translation>
    </message>
</context>
<context>
    <name>ProfilesImportActions</name>
    <message>
        <source>Import profiles...</source>
        <translation>Importuj profil...</translation>
    </message>
    <message>
        <source>Import external profile...</source>
        <translation>Importuj zewnętrzny profil...</translation>
    </message>
</context>
</TS>
